

-------- part event INSPECT_READY

function EA_PLM:UpdateGroupInfoCache(unit)
	local name = PLM_GetFullName(unit)

	if name ~= nil then
		local characterDetails
		if groupInfoCache[name] == nil then
			characterDetails = {}
			local _, class = UnitClass(unit)
			characterDetails[CLASS_NAME] = class
			local spec = GetInspectSpecialization(unit)
			characterDetails[SPEC] = spec
			local level = UnitLevel(unit)
			characterDetails[PL_LEVEL] = level
			characterDetails[FORCE_REFRESH] = false
		else
			characterDetails = groupInfoCache[name]
		end
		
		local updatedItemCount = 0
		local item
		for invslot = _G.INVSLOT_FIRST_EQUIPPED, _G.INVSLOT_LAST_EQUIPPED do
			if invslot ~= _G.INVSLOT_BODY and invslot ~= INVSLOT_TABARD then -- ignore chemise/tabard
				item = GetInventoryItemLink(UnitName(unit), invslot)
				if item ~= nil then
					if characterDetails[invslot] == nil or characterDetails[invslot] ~= item then
						updatedItemCount = updatedItemCount + 1
						characterDetails[invslot] = item
					end
				end
			end
		end

		if updatedItemCount > 0 or groupInfoCache[name] == nil then
			groupInfoCache[name] = characterDetails
		end
		
		if groupInfoCache[name][FORCE_REFRESH] == true then
			groupInfoCache[name][FORCE_REFRESH] = false
		end
		
		--print('      Updated ' .. updatedItemCount .. ' items for ' .. name)
	end
end

function EA_PLM:InspectReadyEvent(self, event, ...)
	local guid = select(1, ...)
	local name = select(6, GetPlayerInfoByGUID(guid))
	if notifyInspectName ~= nil and (notifyInspectName == name or notifyInspectName == PLM_GetFullName(name)) then
		EA_PLM:UpdateGroupInfoCache(name)
		if not InspectFrame or not InspectFrame:IsShown() then
			ClearInspectPlayer()
		end
		notifyInspectName = nil
	end
end

---------------------------------
-------- part event CHAT_MSG_LOOT

function EA_PLM:AnnounceLoot(text, group_type)
	SendChatMessage(text, group_type)
end

function EA_PLM:AddLootedItem(fullItemInfo, characterName, status)
	local lootedItemIndex = #lootedItems + 1

	lootedItems[lootedItemIndex] = {}
	lootedItems[lootedItemIndex][LOOTER_NAME] = characterName
	lootedItems[lootedItemIndex][FULL_ITEM_INFO] = fullItemInfo
	if IsPlayer(characterName) then
		lootedItems[lootedItemIndex][STATUS] = status
	else
		lootedItems[lootedItemIndex][STATUS] = status
	end
	
	----BEGIN HERE
	local lootedItem = lootedItems[lootedItemIndex]
	local text = "EA_PLM: "
	if Config[PLM_PROMPT_CHAT] == PLM_CHAT_ALWAYS or (Config[PLM_PROMPT_CHAT] == PLM_CHAT_IFRL and UnitIsGroupLeader("player") == true) then
		
		text = text .. Ambiguate(lootedItem[LOOTER_NAME], 'short') .. " " .. L["MSG_CAN_TRADE"] .. " " .. lootedItem[FULL_ITEM_INFO][FII_ITEM]
		text = text .. "(" .. lootedItem[FULL_ITEM_INFO][FII_REAL_ILVL] .. ") ".. L["MSG_WITH"] .. " "
		
		local isAnUpgradeForAnyCharacter, isAnUpgradeForAnyCharacterNames = EA_PLM:IsAnUpgradeForAnyCharacter(lootedItem[FULL_ITEM_INFO])
		
		if (PLM_GetFullName('player') ~= characterName) then
			local isAnUpgrade = EA_PLM:IsEquippableItemForCharacter(fullItemInfo, PLM_GetFullName('player'))
				local arg1, arg2 = EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, PLM_GetFullName('player'), 0)
				if isAnUpgrade and arg1 == true then
					table.insert(isAnUpgradeForAnyCharacterNames, Ambiguate(PLM_GetFullName('player'), 'short'))
					isAnUpgradeForAnyCharacter = true
				end
			end
		
		for isUpIndex = 1, #isAnUpgradeForAnyCharacterNames do
			local tmp = isAnUpgradeForAnyCharacterNames[isUpIndex]

			text = text .. tmp
			if isUpIndex ~= #isAnUpgradeForAnyCharacterNames then
				text = text .. ", "
			end
		end
		
		if IsInGroup(LE_PARTY_CATEGORY_INSTANCE) then
			C_Timer.After(Config[PLM_DELAY_CHAT], function() EA_PLM:AnnounceLoot(text, "INSTANCE_CHAT") end)
		else
			if IsInRaid() then
				C_Timer.After(Config[PLM_DELAY_CHAT], function() EA_PLM:AnnounceLoot(text, "RAID") end)
			else
				C_Timer.After(Config[PLM_DELAY_CHAT], function() EA_PLM:AnnounceLoot(text, "PARTY") end)
			end
		end
	end
	------END HERE
	
	
	
	return lootedItemIndex
end

function EA_PLM:shouldAddLootedItem(fullItemInfo)
	return EA_PLM:IsEquippableItemForCharacter(fullItemInfo, PLM_GetFullName('player')) and
		((Config[PLH_PREFS_INCLUDE_XMOG] and fullItemInfo[FII_XMOGGABLE]) or EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, PLM_GetFullName('player'), Config[PLM_ILVL_THRESHOLD]))
end

function EA_PLM:PerformNotify(fullItemInfo, looterName)
	if ShouldBeEvaluated(fullItemInfo) then
	
	looterName = looterName:gsub("%s", "")
	
		if Config[PLM_CONF_RL_MODE] == true then
			local isTradeable = not EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, looterName, 0)
			if fullItemInfo[FII_BIND_TYPE] ~= LE_ITEM_BIND_ON_EQUIP and isTradeable then
			
			
				local isAnUpgradeForAnyCharacter, isAnUpgradeForAnyCharacterNames = EA_PLM:IsAnUpgradeForAnyCharacter(fullItemInfo)
				
				
		
				local isAnUpgrade = EA_PLM:IsEquippableItemForCharacter(fullItemInfo, PLM_GetFullName('player'))
				local arg1, arg2 = EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, PLM_GetFullName('player'), 0)
				if isAnUpgrade and arg1 == true then
					table.insert(isAnUpgradeForAnyCharacterNames, Ambiguate(PLM_GetFullName('player'), 'short'))
					isAnUpgradeForAnyCharacter = true
				end
				
				
				if isAnUpgradeForAnyCharacter then	
					EA_PLM:AddLootedItem(fullItemInfo, looterName, STATUS_RL_LOOT)
					EA_PLM:UpdateDisplayFrame()
				else
					if Config[PLM_XMOG_UP] == true and IsPlayer(looterName) == false then
						if fullItemInfo[FII_XMOGGABLE] and EA_PLM:IsEquippableItemForCharacter(fullItemInfo, PLM_GetFullName('player')) == true then
							EA_PLM:AddLootedItem(fullItemInfo, looterName, STATUS_XMOG)
							EA_PLM:UpdateDisplayFrame()
						end
					end
				end
			end	
		elseif IsPlayer(looterName) then	

			local isTradeable = not EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, looterName, 0)
			if isTradeable then	

				local isAnUpgradeForAnyCharacter, isAnUpgradeForAnyCharacterNames = EA_PLM:IsAnUpgradeForAnyCharacter(fullItemInfo)
--print("   isAnUpgradeForAnyCharacter = ", isAnUpgradeForAnyCharacter)
		
		
		
		
					if isAnUpgradeForAnyCharacter then	
						--print("et c'est le gg2")
						EA_PLM:AddLootedItem(fullItemInfo, looterName, STATUS_SELF_LOOT)
						EA_PLM:UpdateDisplayFrame()
					end
			
		
			end
		elseif fullItemInfo[FII_BIND_TYPE] ~= LE_ITEM_BIND_ON_EQUIP and not EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, looterName, 0) then
			--print("EA_PLM:shouldAddLootedItem(fullItemInfo)=  ", EA_PLM:shouldAddLootedItem(fullItemInfo))
			if EA_PLM:shouldAddLootedItem(fullItemInfo) then
				--print("et c'est le gg1")
				EA_PLM:AddLootedItem(fullItemInfo, looterName, STATUS_OTHER_LOOT)
				EA_PLM:UpdateDisplayFrame()
			else
				if Config[PLM_XMOG_UP] == true then
					if fullItemInfo[FII_XMOGGABLE] and EA_PLM:IsEquippableItemForCharacter(fullItemInfo, PLM_GetFullName('player')) == true then
						EA_PLM:AddLootedItem(fullItemInfo, looterName, STATUS_XMOG)
						EA_PLM:UpdateDisplayFrame()
					end
				end
			end
		end
	end
end

function EA_PLM:IsAnUpgradeForAnyCharacter(fullItemInfo)
	local isAnUpgrade, equippedILVL
	local isAnUpgradeForAnyCharacterNames = {}

	local index = 1
	local characterName
	while GetRaidRosterInfo(index) ~= nil do
		characterName = PLM_GetFullName(select(1, GetRaidRosterInfo(index)))
--print("   characterName = ", characterName)		
		if not IsPlayer(characterName) and EA_PLM:IsEquippableItemForCharacter(fullItemInfo, characterName) then
--print("      isEquippable = true")		
			isAnUpgrade, equippedILVL = EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, characterName, 0) -- -50 pour les test ici
			if isAnUpgrade then
--print("      isAnUpgrade!")		
				isAnUpgradeForAnyCharacterNames[#isAnUpgradeForAnyCharacterNames + 1] = Ambiguate(characterName, 'short') .. ' (' .. equippedILVL .. ')'
			end
		end
		index = index + 1
	end
	return #isAnUpgradeForAnyCharacterNames > 0, isAnUpgradeForAnyCharacterNames
end

function EA_PLM:IsEquippableItemForCharacter(fullItemInfo, characterName)
	local characterClass
	local characterSpec
	local characterLevel

	if fullItemInfo ~= nil and characterName ~= nil and fullItemInfo[FII_IS_EQUIPPABLE] then
		if IsPlayer(characterName) then
			_, characterClass = UnitClass('player')
			characterSpec = GetSpecializationInfo(GetSpecialization())
			characterLevel = UnitLevel('player')
		elseif groupInfoCache[characterName] ~= nil then
			characterClass = groupInfoCache[characterName][CLASS_NAME]
			characterSpec = groupInfoCache[characterName][SPEC]
			characterLevel = groupInfoCache[characterName][PL_LEVEL]
		else
			--print('Unable to determine class and spec in InEquippableItemForCharacter()!!!! for ' .. characterName)
			return true  -- should never reach here, but if we do it means we're not looking up the player or anyone in cache
		end

		if fullItemInfo[FII_REQUIRED_LEVEL] > characterLevel and not IsPlayer(characterName) then
			return false
		end
		
		if fullItemInfo[FII_CLASSES] ~= nil then	-- check whether to item is a class restricted item (ex: tier)
			if not string.find(characterClass, fullItemInfo[FII_CLASSES]) then
				return false
			end
		end
		
		if fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_CLOAK' or fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_FINGER' or fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_NECK' then
			return true
		end

		if fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_TRINKET' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_WEAPON' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_SHIELD' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_2HWEAPON' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_WEAPONMAINHAND' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_WEAPONOFFHAND' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_HOLDABLE' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_RANGED' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_THROWN' or
			fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_RANGEDRIGHT' then
			
			local itemPrimaryAttribute = GetItemPrimaryAttribute(fullItemInfo[FII_ITEM])
			if itemPrimaryAttribute ~= nil then
				local isValidPrimaryAttribute = false
				for _, spec in pairs(SPEC_BY_CLASS[characterClass]) do
					if characterSpec == spec or not Config[PLM_CURRENT_SPEC_ONLY] then
						if PRIMARY_ATTRIBUTE_BY_SPEC[spec] == itemPrimaryAttribute then
							isValidPrimaryAttribute = true
							break;
						end
					end
				end
				if not isValidPrimaryAttribute then
					return false
				end
			end
		end

		if fullItemInfo[FII_ITEM_EQUIP_LOC] == 'INVTYPE_TRINKET' then
			for _, spec in pairs(SPEC_BY_CLASS[characterClass]) do
				if characterSpec == spec or not Config[PLM_CURRENT_SPEC_ONLY] then
					if IsTrinketUsable(fullItemInfo[FII_ITEM], ROLE_BY_SPEC[spec]) then
						return true
					end
				end
			end
			return IsTrinketUsable(fullItemInfo[FII_ITEM], PLH_ROLE_UNKNOWN) == true
		else
			local subClasses		
			for _, spec in pairs(SPEC_BY_CLASS[characterClass]) do
				if characterSpec == spec or not Config[PLM_CURRENT_SPEC_ONLY] then
					if fullItemInfo[FII_CLASS] == LE_ITEM_CLASS_ARMOR then
						subClasses = EQUIPPABLE_ARMOR_BY_SPEC[spec]
					else
						subClasses = EQUIPPABLE_WEAPON_BY_SPEC[spec]
					end
					for _, subClass in pairs(subClasses) do
						if subClass == fullItemInfo[FII_SUB_CLASS] then
							return true
						end
					end
				end
			end
		end
	end
	return false
end

function EA_PLM:IsAnUpgradeForCharacter(fullItemInfo, characterName, threshold)
	local itemEquipLoc = fullItemInfo[FII_ITEM_EQUIP_LOC]
	local itemRealILVL = fullItemInfo[FII_REAL_ILVL]
		
	if IsInRaid() and (itemEquipLoc == 'INVTYPE_HEAD' or itemEquipLoc == 'INVTYPE_SHOULDER' or itemEquipLoc == 'INVTYPE_ROBE' or itemEquipLoc == 'INVTYPE_CHEST') then
	
		local stat_table = GetItemStats(fullItemInfo[FII_ITEM])
		local nb_stat = #stat_table
		if stat_table[RESISTANCE0_NAME] ~= nil then nb_stat = nb_stat - 1 end
		
		if nb_stat == 2 then
			return false, 0
		end
		
	end
	
	
	local equippedItem1 = nil
	local isAnUpgrade1 = false
	local equippedILVL1 = 0
	local equippedItem2 = nil
	local isAnUpgrade2 = false
	local equippedILVL2 = 0
	local slotID
	
	if itemEquipLoc ~= nil and itemEquipLoc ~= '' then
		if itemEquipLoc == 'INVTYPE_FINGER' then
			equippedItem1 = GetEquippedItem(characterName, INVSLOT_FINGER1)
			equippedItem2 = GetEquippedItem(characterName, INVSLOT_FINGER2)
		elseif itemEquipLoc == 'INVTYPE_TRINKET' then
			equippedItem1 = GetEquippedItem(characterName, INVSLOT_TRINKET1)
			equippedItem2 = GetEquippedItem(characterName, INVSLOT_TRINKET2)
		elseif itemEquipLoc == 'INVTYPE_WEAPON' or itemEquipLoc == 'INVTYPE_HOLDABLE' then	
			equippedItem1 = GetEquippedItem(characterName, INVSLOT_MAINHAND)
			equippedItem2 = GetEquippedItem(characterName, INVSLOT_OFFHAND)
			if equippedItem2 ~= nil and select(9, GetItemInfo(equippedItem2)) == 'INVTYPE_SHIELD' then
				equippedItem2 = nil		-- ignore this slot if we have a shield equipped in offhand
			end
		else
			slotID = GetSlotID(itemEquipLoc)
			equippedItem1 =  GetEquippedItem(characterName, slotID)
		end
		if equippedItem2 ~= nil then
			isAnUpgrade1, equippedILVL1 = IsAnUpgrade(itemRealILVL, equippedItem1, threshold)
			isAnUpgrade2, equippedILVL2 = IsAnUpgrade(itemRealILVL, equippedItem2, threshold)
			
			if itemEquipLoc == 'INVTYPE_HOLDABLE' then
				isAnUpgrade1 = isAnUpgrade2
				equippedILVL1 = equippedILVL2
			elseif L["WEAPON_TYPE"] == fullItemInfo[FII_SUB_TYPE] then
				isAnUpgrade1 = isAnUpgrade1 and isAnUpgrade2
				equippedILVL1 = max(equippedILVL1, equippedILVL2)
			else
				isAnUpgrade1 = isAnUpgrade1 or isAnUpgrade2
				equippedILVL1 = min(equippedILVL1, equippedILVL2)
			end
		else
			isAnUpgrade1, equippedILVL1 = IsAnUpgrade(itemRealILVL, equippedItem1, threshold)
		end
	end
	return isAnUpgrade1, equippedILVL1
end

function EA_PLM:GetFullItemInfo(item)
	local ITEM_CLASSES_ALLOWED_PATTERN = _G.ITEM_CLASSES_ALLOWED:gsub('%%s', '(.+)')		-- Classes: (.+)
	local BIND_TRADE_TIME_REMAINING_PATTERN = _G.BIND_TRADE_TIME_REMAINING:gsub('%%s', '(.+)')  -- You may trade this item with players that were also eligible to loot this item for the next (.+).
	local TRANSMOGRIFY_TOOLTIP_APPEARANCE_UNKNOWN_PATTERN = _G.TRANSMOGRIFY_TOOLTIP_APPEARANCE_UNKNOWN:gsub('%%s', '(.+)')			-- You haven't collected this appearance
	local TRANSMOGRIFY_TOOLTIP_ITEM_UNKNOWN_APPEARANCE_KNOWN_PATTERN = _G.TRANSMOGRIFY_TOOLTIP_ITEM_UNKNOWN_APPEARANCE_KNOWN:gsub('%%s', '(.+)')	-- You've collected this appearance, but not from this item
	local fullItemInfo = {}

	if item ~= nil then
		fullItemInfo[FII_ITEM] = item
		
		_, _, fullItemInfo[FII_QUALITY], fullItemInfo[FII_BASE_ILVL], fullItemInfo[FII_REQUIRED_LEVEL], _, _, _, fullItemInfo[FII_ITEM_EQUIP_LOC], _, _, fullItemInfo[FII_CLASS], fullItemInfo[FII_SUB_CLASS], fullItemInfo[FII_BIND_TYPE], _, _, _ = GetItemInfo(item)
		fullItemInfo[FII_IS_EQUIPPABLE] = IsEquippableItem(item)
		
		if fullItemInfo[FII_IS_EQUIPPABLE] then

			tooltipLong = tooltipLong or PLM_CreateEmptyTooltip(30)
			tooltipLong:ClearLines()
			tooltipLong:SetHyperlink(item)

			-- determine the real iLVL
			local realILVL = GetILVLFromTooltip(tooltipLong)
			if realILVL == nil then
				realILVL = fullItemInfo[FII_BASE_ILVL]
			end
			fullItemInfo[FII_REAL_ILVL] = tonumber(realILVL)

			local classes = nil
			local hasBindTradeTimeWarning = nil
			local hasSocket = false
			local hasAvoidance = false
			local hasIndestructible = false
			local hasLeech = false
			local hasSpeed = false
			local xmoggable = false
			
			local text
			local index = 6 -- the elements we're looking for are all further down in the tooltip
			while tooltipLong.leftside[index] do
				text = tooltipLong.leftside[index]:GetText()
				if text ~= nil then
					hasBindTradeTimeWarning = hasBindTradeTimeWarning or text:match(BIND_TRADE_TIME_REMAINING_PATTERN)
					classes = classes or text:match(ITEM_CLASSES_ALLOWED_PATTERN)
					hasSocket = hasSocket or text:find(_G.EMPTY_SOCKET_PRISMATIC) == 1
					hasAvoidance = hasAvoidance or text:find(_G.STAT_AVOIDANCE) ~= nil
					hasIndestructible = hasIndestructible or text:find(_G.STAT_STURDINESS) == 1
					hasLeech = hasLeech or text:find(_G.STAT_LIFESTEAL) ~= nil
					hasSpeed = hasSpeed or text:find(_G.STAT_SPEED) ~= nil
					xmoggable = xmoggable or text:find(TRANSMOGRIFY_TOOLTIP_APPEARANCE_UNKNOWN_PATTERN) ~= nil or text:find(TRANSMOGRIFY_TOOLTIP_ITEM_UNKNOWN_APPEARANCE_KNOWN_PATTERN) ~= nil
				end
				index = index + 1
			end

			if classes ~= nil then
				classes = string.upper(classes)
				classes = string.gsub(classes, ' ', '')  -- remove space for dh and dk
			end
			
			fullItemInfo[FII_CLASSES] = classes
			fullItemInfo[FII_TRADE_TIME_WARNING_SHOWN] = hasBindTradeTimeWarning
			fullItemInfo[FII_HAS_SOCKET] = hasSocket
			fullItemInfo[FII_HAS_AVOIDANCE] = hasAvoidance
			fullItemInfo[FII_HAS_INDESTRUCTIBLE] = hasIndestructible
			fullItemInfo[FII_HAS_LEECH] = hasLeech
			fullItemInfo[FII_HAS_SPEED] = hasSpeed
			fullItemInfo[FII_XMOGGABLE] = xmoggable
		end
	end
	
	--print("c'est bon full item info ok")
	return fullItemInfo
end


function EA_PLM:LootReceivedEvent(self, event, ...)
	local LOOT_ITEM_SELF_PATTERN = _G.LOOT_ITEM_SELF:gsub('%%s', '(.+)')  -- You receive loot: (.+)
	local LOOT_ITEM_PATTERN	= _G.LOOT_ITEM:gsub('%%s', '(.+)')  -- (.+) receives loot: (.+)
	
	local message, _, _, _, looter = ...
	local lootedItem = message:match(LOOT_ITEM_SELF_PATTERN)
	if lootedItem == nil then
		_, lootedItem = message:match(LOOT_ITEM_PATTERN)
	end

	--print("test ici ?")
	--print(looter)
	--print(lootedItem)
	if lootedItem then
		local fullItemInfo = EA_PLM:GetFullItemInfo(lootedItem)
		EA_PLM:PerformNotify(fullItemInfo, PLM_GetFullName(looter))
	end
end