
function ProcessEvent(self, event, ...)
	if event == 'CHAT_MSG_LOOT' then
		EA_PLM:LootReceivedEvent(self, event, ...)
	elseif event == 'CHAT_MSG_ADDON' then
		EA_PLM:GetMsgAddon(self, event, ...)
	elseif event == 'INSPECT_READY' then
		EA_PLM:InspectReadyEvent(self, event, ...)
	elseif event == 'PLAYER_REGEN_DISABLED' then
		EA_PLM:PopulateGroupInfoCache()
	elseif event == 'PLAYER_SPECIALIZATION_CHANGED' or event == 'UNIT_INVENTORY_CHANGED' then
		EA_PLM:PopulateGroupInfoCache()
	end
end

-------- part loaded event
function EA_PLM:InspectGroupMember(characterName)
	if not IsPlayer(characterName) then
		if CanInspect(characterName) and (not InspectFrame or not InspectFrame:IsShown()) then
			NotifyInspect(characterName)
			notifyInspectName = characterName
			C_Timer.After(DELAY_BETWEEN_INSPECTIONS, function() EA_PLM.PLM_InspectNextGroupMember() end)
			return true
		else
			--print('   Unable to inspect ' .. characterName)
		end
	end
	return false
end

function EA_PLM:PLM_InspectNextGroupMember()
	local characterName
	local queuedAnInspection = false
	local spec

	notifyInspectName = nil
	
	while inspectIndex <= maxInspectIndex  and not queuedAnInspection do
		characterName = select(1, GetRaidRosterInfo(inspectIndex))
		if characterName ~= nil and not IsPlayer(characterName) then	-- safeguard;
			local fullname = PLM_GetFullName(characterName)
			if fullname ~= nil then
				if groupInfoCache[fullname] ~= nil then
					spec = groupInfoCache[fullname][SPEC]
				end

				if GetItemCountFromCache(fullname) < GetExpectedItemCount(spec) then  -- if we've already cached 15 or more items, don't bother refreshing
					queuedAnInspection = EA_PLM:InspectGroupMember(characterName)
				end
			end
		end
		inspectIndex = inspectIndex + 1
	end
	if inspectIndex > maxInspectIndex then				-- that means we just completed our current loop
		inspectLoop = inspectLoop + 1
		if inspectLoop <= MAX_INSPECT_LOOPS then		-- let's start the next loop
			inspectIndex = 1
			if not queuedAnInspection then				-- if we just queued someone for inspection, we don't need to do anything else to start the new loop since InspectGroupMember will call PLH_InspectNextGroupMember()
				EA_PLM.PLM_InspectNextGroupMember()
			end
		elseif not queuedAnInspection then				-- we've finished all loops
			debug_print_cache()
		end
	end
end

function EA_PLM:PopulateGroupInfoCache()
	local now = time()
	
	if now - priorCacheRefreshTime > MIN_DELAY_BETWEEN_CACHE_REFRESHES then
		priorCacheRefreshTime = now
	
		-- remove characters from the cache if they're no long in the raid/party
		for name, details in pairs(groupInfoCache) do
			if not IsCharacterInGroup(name) then
				groupInfoCache[name] = nil
			end
		end

		if IsInGroup() then
			if inspectLoop == 0 or (inspectIndex > maxInspectIndex and inspectLoop > MAX_INSPECT_LOOPS) then
				inspectLoop = 1
				inspectIndex = 1
				maxInspectIndex = GetNumGroupMembers()
				EA_PLM.PLM_InspectNextGroupMember()
			end
		end
	end
end

function EA_PLM:Enable()
	--print('Enabling EA_PLM')
	isEnabled = true
	priorCacheRefreshTime = 0
	groupInfoCache = {}
	eventHandlerFrame:RegisterEvent('CHAT_MSG_LOOT')
	eventHandlerFrame:RegisterEvent('INSPECT_READY')
	eventHandlerFrame:RegisterEvent('PLAYER_REGEN_DISABLED')
	eventHandlerFrame:RegisterEvent('PLAYER_SPECIALIZATION_CHANGED')
	eventHandlerFrame:RegisterEvent('UNIT_INVENTORY_CHANGED')
end

function EA_PLM:Disable()
	--print('Disabling EA_PLM')
	isEnabled = false
	priorCacheRefreshTime = 0
	groupInfoCache = {}
	eventHandlerFrame:UnregisterAllEvents()
end

function EA_PLM:EnableOrDisable()
	local inInstance, instanceType = IsInInstance() --get instance
	local isPersonalLoot = (IsInGroup(LE_PARTY_CATEGORY_INSTANCE) or (IsInGroup() and GetLootMethod() == 'personalloot'))
		and (instanceType == "party" or instanceType == "raid") -- check in group/raid/lfr/lfg etc
	local shouldBeEnabled = isPersonalLoot
	
	if not isEnabled and shouldBeEnabled then	--active car en group/raid/lfr/lfg etc
		EA_PLM.Enable()
	elseif isEnabled and not shouldBeEnabled then --desactive car pas en group/raid/lfr/lfg etc
		EA_PLM.Disable()
	end
	
	if isEnabled then 
		EA_PLM.PopulateGroupInfoCache()
	end
end

function EA_PLM:EnableOrDisableEvent(self, event, ...)
	C_Timer.After(2, function() EA_PLM.EnableOrDisable() end)
end

function EA_PLM:AddonLoadedEvent()
	
		if enableOrDisableEventFrame == nil then
			enableOrDisableEventFrame = CreateFrame('Frame')
			enableOrDisableEventFrame:SetScript('OnEvent', EA_PLM.EnableOrDisableEvent)
			enableOrDisableEventFrame:RegisterEvent('GROUP_ROSTER_UPDATE')
			enableOrDisableEventFrame:RegisterEvent('ZONE_CHANGED_NEW_AREA')
			enableOrDisableEventFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
		end
		eventHandlerFrame:RegisterEvent('CHAT_MSG_ADDON')
		C_ChatInfo.RegisterAddonMessagePrefix("EAPLM")
		EA_PLM:CreateLootedItemsDisplay()
end