
function EA_PLM:SaveMainWindowPosition()
	local xOfs, yOfs = lootedItemsFrame:GetCenter()
	local s = lootedItemsFrame:GetEffectiveScale()
	local uis = UIParent:GetScale()
	xOfs = xOfs * s - GetScreenWidth() * uis / 2
	yOfs = yOfs * s - GetScreenHeight() * uis / 2

	Config[PLM_LOOTED_ITEMS_FRAME_X] = xOfs / uis
	Config[PLM_LOOTED_ITEMS_FRAME_Y] = yOfs / uis
	Config[PLM_LOOTED_ITEMS_FRAME_WIDTH] = lootedItemsFrame:GetWidth()
	Config[PLM_LOOTED_ITEMS_FRAME_HEIGHT] = lootedItemsFrame:GetHeight()
end

function EA_PLM:RestoreMainWindowPosition()
	x = Config[PLM_LOOTED_ITEMS_FRAME_X]
	y = Config[PLM_LOOTED_ITEMS_FRAME_Y]
	width = Config[PLM_LOOTED_ITEMS_FRAME_WIDTH]
	height = Config[PLM_LOOTED_ITEMS_FRAME_HEIGHT]

	local s = lootedItemsFrame:GetEffectiveScale()
	local uis = UIParent:GetScale()
	lootedItemsFrame:SetPoint("CENTER", UIParent, "CENTER", x * uis / s, y * uis / s)
	lootedItemsFrame:SetWidth(width)
	lootedItemsFrame:SetHeight(height)
end

function EA_PLM:IsWidgetVisible(widget, tolerance)
	if widget == nil then
		return false
	else
		if tolerance == nil then
			tolerance = 0
		end
		local widgetTop = widget:GetTop()
		local lootedItemFramesBottom = lootedItemsFrame:GetBottom()
		local widgetBottom = widget:GetBottom()
		local lootedItemFramesTop = lootedItemsFrame:GetTop()
		if widgetTop ~= nil and lootedItemFramesBottom ~= nil and widgetBottom ~= nil and lootedItemFramesTop ~= nil then
			return widgetTop > lootedItemFramesBottom + tolerance and widgetBottom < lootedItemFramesTop + tolerance
		else
			return false
		end
	end
end

function EA_PLM:HideOffScreenWidgets()
	if contentFrame ~= nil then
		for i = 1, buttonIndex do
			if EA_PLM:IsWidgetVisible(buttons[i], 0) then
				buttons[i]:Show()
			else
				buttons[i]:Hide()
			end
		end	

		for i = 1, itemFrameIndex do
			if EA_PLM:IsWidgetVisible(itemFrames[i], 0) then
				itemFrames[i]:Show()
			else
				itemFrames[i]:Hide()
			end
		end	
		
		for lootedItemIndex, requestors in pairs(radioButtons) do
			for requestorIndex, radioButton in pairs(requestors) do
				if EA_PLM:IsWidgetVisible(radioButton, 0) and lootedItems[lootedItemIndex][STATUS] == STATUS_REQUESTED then
					radioButton:Show()
				else
					radioButton:Hide()
				end
			end
		end
	end
end

function EA_PLM:CreateLootedItemsDisplay()

	lootedItemsFrame = CreateFrame('Frame', 'PLM_LootedItemsFrame', UIParent, 'TranslucentFrameTemplate')
	
	lootedItemsFrame:SetMovable(true)
	lootedItemsFrame:EnableMouse(true)
	lootedItemsFrame:EnableMouseWheel(true)
	lootedItemsFrame:RegisterForDrag('LeftButton')
	lootedItemsFrame:SetScript('OnDragStart', lootedItemsFrame.StartMoving)
	lootedItemsFrame:SetScript('OnDragStop', function(self)
		lootedItemsFrame:StopMovingOrSizing()
		EA_PLM:SaveMainWindowPosition()
	end)
	lootedItemsFrame:SetResizable(true)
	lootedItemsFrame:SetMinResize(100, 50)
	lootedItemsFrame:SetMaxResize(600, 300)
	
	--print(lootedItemsFrame:GetHeight())
	if lootedItemsFrame:GetHeight() == nil or lootedItemsFrame:GetHeight() == 424 then  	-- first try repositioning/resizing from layout-local.txt
		if Config[PLM_LOOTED_ITEMS_FRAME_X] ~= nil then								-- if we didn't have anything there (ex: after addon was disabled and renabled), try saved variables
			EA_PLM:RestoreMainWindowPosition()
			lootedItemsFrame:SetUserPlaced(true)
		else																			-- if we still couldn't find saved info, just use defaults
			lootedItemsFrame:SetSize(400, 160)
			lootedItemsFrame:SetPoint('CENTER', UIParent, 'CENTER') 
		end
	end

	scrollFrame = CreateFrame('ScrollFrame', nil, lootedItemsFrame) 
	scrollFrame:SetPoint('TOPLEFT', 10, -5) 
	scrollFrame:SetPoint('BOTTOMRIGHT', -10, 5)
	scrollFrame:SetScript("OnVerticalScroll", function(self, offset) EA_PLM:HideOffScreenWidgets() end)
	scrollFrame:SetScript("OnShow", function(self) EA_PLM:HideOffScreenWidgets() end)
	lootedItemsFrame.scrollframe = scrollFrame 


	scrollbar = CreateFrame('Slider', nil, scrollFrame, 'UIPanelScrollBarTemplate')
	scrollbar:SetPoint('TOPLEFT', lootedItemsFrame, 'TOPRIGHT', -27, -28) 
	scrollbar:SetPoint('BOTTOMLEFT', lootedItemsFrame, 'BOTTOMRIGHT', -27, 26)
	scrollbar:SetMinMaxValues(1, 300) 
	scrollbar:SetValueStep(1) 
	scrollbar.scrollStep = 10 
	scrollbar:SetValue(0) 
	scrollbar:SetWidth(16) 
	scrollbar:SetScript('OnValueChanged', function (self, value) self:GetParent():SetVerticalScroll(value) end) 
	lootedItemsFrame.scrollbar = scrollbar 
	scrollbar:Hide()
	
	
	lootedItemsFrame:SetScript('OnMouseWheel', function(self, delta)
		local cur_val = scrollbar:GetValue()
		local min_val, max_val = scrollbar:GetMinMaxValues()

		if delta < 0 and cur_val < max_val then
			cur_val = math.min(max_val, cur_val + 10)
			scrollbar:SetValue(cur_val)
		elseif delta > 0 and cur_val > min_val then
			cur_val = math.max(min_val, cur_val - 10)
			scrollbar:SetValue(cur_val)
		end
	end)

	
	local closeButton = CreateFrame('Button', nil, lootedItemsFrame, 'UIPanelCloseButton')
	closeButton:SetPoint('TOPRIGHT', 6, 6)
	closeButton:SetHeight(25)
	closeButton:SetWidth(25)
	closeButton:SetScript('OnClick', function(self)
		scrollbar:SetValue(0)
		HideParentPanel(self)
	end)
	lootedItemsFrame.closeButton = closeButton
	

	local resizeButton = CreateFrame('Button', nil, lootedItemsFrame)
	resizeButton:SetSize(16, 16)
	resizeButton:SetPoint('BOTTOMRIGHT', -3, 3)
	resizeButton:SetNormalTexture('Interface\\ChatFrame\\UI-ChatIM-SizeGrabber-Up')
	resizeButton:SetHighlightTexture('Interface\\ChatFrame\\UI-ChatIM-SizeGrabber-Highlight')
	resizeButton:SetPushedTexture('Interface\\ChatFrame\\UI-ChatIM-SizeGrabber-Down')
	resizeButton:SetScript('OnMouseDown', function(self, button)
		lootedItemsFrame:StartSizing('BOTTOMRIGHT')
		lootedItemsFrame:SetUserPlaced(true)
	end)
	resizeButton:SetScript('OnMouseUp', function(self, button)
		lootedItemsFrame:StopMovingOrSizing()
		EA_PLM:SaveMainWindowPosition()
	end)
	
	
	lootedItemsFrame:SetScript('OnSizeChanged', function(self, width, height) EA_PLM:HideOffScreenWidgets() end)
	
	
	contentFrame = CreateFrame('Frame', nil, scrollFrame) 
	contentFrame:SetSize(lootedItemsFrame:GetWidth(), lootedItemsFrame:GetHeight()) 
	scrollFrame.content = contentFrame
	scrollFrame:SetScrollChild(contentFrame)
	
	
	lootedItemsFrame:Hide()
end

function EA_PLM:CreateLabel(text, color, anchor, relativePoint, xOffset, yOffset)
	labelIndex = labelIndex + 1

	if labels[labelIndex] == nil then
		labels[labelIndex] = contentFrame:CreateFontString(nil, 'ARTWORK', 'GameFontNormalSmall')
		labels[labelIndex]:SetJustifyH('LEFT')
	else
		labels[labelIndex]:ClearAllPoints()
		labels[labelIndex]:Show()
	end

	if color ~= nil then
		text = color .. text .. _G.FONT_COLOR_CODE_CLOSE
	end
		
	labels[labelIndex]:SetText(text)
	labels[labelIndex]:SetPoint('TOPLEFT', anchor, relativePoint, xOffset, yOffset)

	return labels[labelIndex]
end

function EA_PLM:CreateItemFrame(itemLabel, item, anchor)
	itemFrameIndex = itemFrameIndex + 1
	
	if itemFrames[itemFrameIndex] == nil then
		itemFrames[itemFrameIndex] = CreateFrame('Frame', nil, contentFrame)
		itemFrames[itemFrameIndex]:SetScript('OnLeave', function(self)
			self:SetScript('OnEvent', nil)
			self:UnregisterAllEvents()
			GameTooltip:Hide()
		end)
	else
		itemFrames[itemFrameIndex]:ClearAllPoints()
		itemFrames[itemFrameIndex]:SetScript('OnEnter', nil)
		itemFrames[itemFrameIndex]:SetScript('OnEvent', nil)
		itemFrames[itemFrameIndex]:UnregisterAllEvents()
		itemFrames[itemFrameIndex]:Show()
	end
	
	itemFrames[itemFrameIndex]:SetSize(itemLabel:GetWidth(), itemLabel:GetHeight())
	itemFrames[itemFrameIndex]:SetPoint('TOPLEFT', anchor, 'TOPRIGHT')
	itemFrames[itemFrameIndex]:SetScript('OnEnter', function(self)
		--if IsWidgetVisible(self, 11) then
			GameTooltip:SetOwner(self, 'ANCHOR_CURSOR')
			GameTooltip:SetHyperlink(item)
			GameTooltip:Show()

			self:SetScript('OnEvent', function(self, event, arg, ...)
				if self:IsShown() and event == 'MODIFIER_STATE_CHANGED' and (arg == 'LSHIFT' or arg == 'RSHIFT') then
					GameTooltip:SetOwner(self, 'ANCHOR_CURSOR')
					GameTooltip:SetHyperlink(item)
					GameTooltip:Show()
				end
			end)
			self:RegisterEvent('MODIFIER_STATE_CHANGED')
		--end
	end)
	
	
end

function EA_PLM:CreateButton(text, width, xOffset, yOffset, onClickFunction, ...)
	local color= _G.NORMAL_FONT_COLOR_CODE		
	buttonIndex = buttonIndex + 1

	if buttons[buttonIndex] == nil then
		buttons[buttonIndex] = CreateFrame('Button', nil, contentFrame, 'UIPanelButtonTemplate')
		buttons[buttonIndex]:SetNormalFontObject('GameFontNormalSmall')
	else
		buttons[buttonIndex]:ClearAllPoints()
		buttons[buttonIndex]:SetScript('OnClick', nil)
		buttons[buttonIndex]:SetScript('OnEnter', nil)
		buttons[buttonIndex]:Show()
	end

	buttons[buttonIndex]:SetSize(width, 15)
	buttons[buttonIndex]:SetText(color .. text .. _G.FONT_COLOR_CODE_CLOSE)
	buttons[buttonIndex]:SetPoint('TOPRIGHT', contentFrame, 'TOPRIGHT', xOffset, yOffset)

	if onClickFunction ~= nil then
		local param1, param2 = ...
		buttons[buttonIndex]:SetScript('OnClick', function(self, event, ...)
			onClickFunction(param1, param2)
		end)
	end
	
	return buttons[buttonIndex]
end

function EA_PLM:ClearLootedItemsDisplay()

	local kids = { contentFrame:GetRegions() };
	for _, child in ipairs(kids) do
		child:Hide()
	end	

	local kids = { contentFrame:GetChildren() };
	for _, child in ipairs(kids) do
		child:Hide()
	end	
end

function EA_PLM:GetItemLinkScore(fullItemInfo)
	local itemEquipLoc = fullItemInfo[FII_ITEM_EQUIP_LOC]
	local itemRealILVL = fullItemInfo[FII_REAL_ILVL]

	local equippedItem1 = nil
	local isAnUpgrade1 = false
	local equippedILVL1 = 0
	local equippedItem2 = nil
	local isAnUpgrade2 = false
	local equippedILVL2 = 0
	local slotID
	
	if itemEquipLoc ~= nil and itemEquipLoc ~= '' then
		if itemEquipLoc == 'INVTYPE_FINGER' then
			equippedItem1 = GetEquippedItem(PLM_GetFullName('player'), INVSLOT_FINGER1)
			equippedItem2 = GetEquippedItem(PLM_GetFullName('player'), INVSLOT_FINGER2)
		elseif itemEquipLoc == 'INVTYPE_TRINKET' then
			equippedItem1 = GetEquippedItem(PLM_GetFullName('player'), INVSLOT_TRINKET1)
			equippedItem2 = GetEquippedItem(PLM_GetFullName('player'), INVSLOT_TRINKET2)
		elseif itemEquipLoc == 'INVTYPE_WEAPON' then
			equippedItem1 = GetEquippedItem(PLM_GetFullName('player'), INVSLOT_MAINHAND)
			equippedItem2 = GetEquippedItem(PLM_GetFullName('player'), INVSLOT_OFFHAND)
			if equippedItem2 ~= nil and select(9, GetItemInfo(equippedItem2)) == 'INVTYPE_SHIELD' then
				equippedItem2 = nil		-- ignore this slot if we have a shield equipped in offhand
			end
		else
			slotID = GetSlotID(itemEquipLoc)
			equippedItem1 =  GetEquippedItem(PLM_GetFullName('player'), slotID)
		end
	end
	return equippedItem1, equippedItem2
end

function EA_PLM:CalculItemScore(ItemStat)
	local score = 0
	for k,v in pairs(ItemStat) do
		if k ~= "Class" and k ~= "Spec" then
			local value = Config[PLM_SCALE_VALUE][k]
			if value == nil then
				value = 0
			end
			score = score + (v * value)
		end
    end
	return score
end

function EA_PLM:UpdateDisplayFrame()

	local lootedItem
	local lootedItemStatus

	local verticalOffset = -5
	local VERTICAL_SPACING = -15
	local INDENT = 15
	
	local text
	local color = ITEM_QUALITY_COLORS[6]
	color = color["hex"]
	
	
	local should_display = false
	
	labelIndex = 0
	buttonIndex = 0
	itemFrameIndex = 0

	EA_PLM:ClearLootedItemsDisplay()
	
	for lootedItemIndex = 1, #lootedItems do
		lootedItem = lootedItems[lootedItemIndex]
		lootedItemStatus = lootedItem[STATUS]
		if lootedItemStatus ~= STATUS_HIDDEN then
			should_display = true
		end
	end
	
	if should_display == true then
		for lootedItemIndex = 1, #lootedItems do
			lootedItem = lootedItems[lootedItemIndex]
			lootedItemStatus = lootedItem[STATUS]
					
			--print(lootedItemStatus)
			
			if lootedItemStatus == STATUS_XMOG then
				text = Ambiguate(lootedItem[LOOTER_NAME], 'short') .. " " .. L["MSG_CAN_TRADE"] .. " "
				EA_PLM:CreateLabel(text, color, contentFrame, 'TOPLEFT', 0, verticalOffset)
					
				EA_PLM:CreateLabel(lootedItem[FULL_ITEM_INFO][FII_ITEM], nil, labels[labelIndex], 'TOPRIGHT')
				EA_PLM:CreateItemFrame(labels[labelIndex], lootedItems[lootedItemIndex][FULL_ITEM_INFO][FII_ITEM], labels[labelIndex - 1])
				EA_PLM:CreateButton("OK", 50, -25 - INDENT, verticalOffset, PLM_DoHideItem, lootedItemIndex)
				verticalOffset = verticalOffset + VERTICAL_SPACING
			
				text = ""
				text = text .. "ilvl " .. lootedItem[FULL_ITEM_INFO][FII_REAL_ILVL] .. " "
				text = color .. text .. _G.FONT_COLOR_CODE_CLOSE

				
				text = text .. "|cffffffff"
				text = text .. "+ " .. L["MSG_NO_XMOG"]			
				text = text .. _G.FONT_COLOR_CODE_CLOSE
				if text ~= '' then
					EA_PLM:CreateLabel(text, nil, contentFrame, 'TOPLEFT', 0, verticalOffset)
					verticalOffset = verticalOffset + VERTICAL_SPACING
				end
			
			
			elseif lootedItemStatus ~= STATUS_HIDDEN then	
				
				if lootedItemStatus == STATUS_SELF_LOOT then			
					text = L["MSG_SELF_TRADE"] .. " "
				else
					text = Ambiguate(lootedItem[LOOTER_NAME], 'short') .. " " .. L["MSG_CAN_TRADE"] .. " "
				end
				
				--create label
				
				
				EA_PLM:CreateLabel(text, color, contentFrame, 'TOPLEFT', 0, verticalOffset)
					
				EA_PLM:CreateLabel(lootedItem[FULL_ITEM_INFO][FII_ITEM], nil, labels[labelIndex], 'TOPRIGHT')
				EA_PLM:CreateItemFrame(labels[labelIndex], lootedItems[lootedItemIndex][FULL_ITEM_INFO][FII_ITEM], labels[labelIndex - 1])
					
					
					
				
				
				
				EA_PLM:CreateButton("OK", 50, -25 - INDENT, verticalOffset, PLM_DoHideItem, lootedItemIndex)
				
				verticalOffset = verticalOffset + VERTICAL_SPACING
				
				text = ""
				if not IsPlayer(lootedItem[LOOTER_NAME]) and Config[PLM_CONF_RL_MODE] == false then
					text = text .. GetilvlDifference(lootedItem, PLM_GetFullName('player')) .. " "
				else
					text = text .. "ilvl " .. lootedItem[FULL_ITEM_INFO][FII_REAL_ILVL] .. " "
				end
					
				if text ~= "" then
				text = color .. text .. _G.FONT_COLOR_CODE_CLOSE
					EA_PLM:CreateLabel(text, nil, contentFrame, 'TOPLEFT', 0, verticalOffset)
				end
				
				
				if Config[PLM_CONF_RL_MODE] == false and EA_PLM:IsEquippableItemForCharacter(lootedItem[FULL_ITEM_INFO], PLM_GetFullName('player')) == true and Config[PLM_CONF_USE_SW_SCORE] == true and Config[PLM_SCALE_VALUE] ~= nil then
					text = "- P: "
					local stats_loot = GetItemStats(lootedItem[FULL_ITEM_INFO][FII_ITEM])
					
					local lootScore = EA_PLM:CalculItemScore(stats_loot)
					local equippedItem1, equippedItem2 = EA_PLM:GetItemLinkScore(lootedItem[FULL_ITEM_INFO])
					local equipScore1 = EA_PLM:CalculItemScore(GetItemStats(equippedItem1))
					if equippedItem2 ~= nil then
						local equipScore2 = EA_PLM:CalculItemScore(GetItemStats(equippedItem2))
						if equipScore2 < equipScore1 then
							equipScore1 = equipScore2
						end
					end
					
					local percent = math.floor(((lootScore - equipScore1) / lootScore * 100) + 0.5)
					if lootScore > equipScore1 then
						text = text .. color .. lootScore .. "(|r" .. "|TInterface\\AddOns\\Pawn\\Textures\\UpgradeArrow.tga:0|t|cFF00FF00" .. percent .. "%|r" .. color .. ")|r"
					else
						text = text .. color .. lootScore .. "(|r" .. "|TInterface\\AddOns\\Pawn\\Textures\\DowngradeArrow.tga:0|t|cFFFF0000" .. percent .. "%|r" .. color .. ")|r"

					end
					EA_PLM:CreateLabel(text, nil, labels[labelIndex], 'TOPRIGHT')
				end
				
				
				--ADDITIONNAL STAT
				text = "|cffffffff"
				if hasBonus(lootedItem[FULL_ITEM_INFO]) then
					--text = color
					if lootedItem[FULL_ITEM_INFO][FII_HAS_SOCKET] then
						text = text .. "+" .. L["MSG_SOCKET"] .. " "
					end
					if lootedItem[FULL_ITEM_INFO][FII_HAS_SPEED] then
						text = text .. "+" .. _G.STAT_SPEED .. " "
					end
					if lootedItem[FULL_ITEM_INFO][FII_HAS_LEECH] then
						text = text .. "+" .. _G.STAT_LIFESTEAL .. " "
					end
					if lootedItem[FULL_ITEM_INFO][FII_HAS_AVOIDANCE] then
						text = text .. "+" .. _G.STAT_AVOIDANCE .. " "
					end
					if lootedItem[FULL_ITEM_INFO][FII_HAS_INDESTRUCTIBLE] then
						text = text .. "+" .. _G.STAT_STURDINESS .. " "
					end
					--text = text .. _G.FONT_COLOR_CODE_CLOSE
				end
				if Config[PLM_CONF_RL_MODE] == false and not IsPlayer(lootedItem[LOOTER_NAME]) and lootedItem[FULL_ITEM_INFO][FII_XMOGGABLE] and Config[PLM_INCLUDE_XMOG] == true then
					text = text .. "+ " .. L["MSG_NO_XMOG"]
				elseif  Config[PLM_CONF_RL_MODE] == true and Config[PLM_INCLUDE_XMOG] == true and not IsPlayer(lootedItem[LOOTER_NAME]) and lootedItem[FULL_ITEM_INFO][FII_XMOGGABLE] and EA_PLM:IsEquippableItemForCharacter(lootedItem[FULL_ITEM_INFO], PLM_GetFullName('player')) == true then
					text = text .. "+ " .. L["MSG_NO_XMOG"]
				end

				
				text = text .. _G.FONT_COLOR_CODE_CLOSE
				--print(text)
				if text ~= '' then
					EA_PLM:CreateLabel(text, nil, labels[labelIndex], 'TOPRIGHT')
					verticalOffset = verticalOffset + VERTICAL_SPACING
				end
				
				
				
				
				text = ""
				if lootedItemStatus == STATUS_SELF_LOOT or Config[PLM_CONF_RL_MODE] == true then
					text = L["MSG_WITH"] .. ": "
					local isAnUpgradeForAnyCharacter, isAnUpgradeForAnyCharacterNames = EA_PLM:IsAnUpgradeForAnyCharacter(lootedItem[FULL_ITEM_INFO])
					
					
					local isAnUpgrade = EA_PLM:IsEquippableItemForCharacter(lootedItem[FULL_ITEM_INFO], PLM_GetFullName('player'))
					local arg1, arg2 = EA_PLM:IsAnUpgradeForCharacter(lootedItem[FULL_ITEM_INFO], PLM_GetFullName('player'), 0)
					if isAnUpgrade and arg1 == true then
						table.insert(isAnUpgradeForAnyCharacterNames, PLM_GetFullName('player') .. " (" .. arg2 .. ")")
					end
					
					local isUpIndex
					for isUpIndex = 1, #isAnUpgradeForAnyCharacterNames do

					
					
						local tmp = isAnUpgradeForAnyCharacterNames[isUpIndex]
						chunks = {}
						for substring in tmp:gmatch("%S+") do
							table.insert(chunks, substring)
						end

						local fullName = PLM_GetFullName(chunks[1])
						--print("chuck", fullName)
						
						if IsPlayer(fullName) then
							local localizedClass, englishClass, classIndex = UnitClass('player')
							characterClass = englishClass
							--print("characterClass", characterClass)
						else
							characterClass = groupInfoCache[fullName][CLASS_NAME]
						end
						--print("after chunk", characterClass)
					
						text = text .. "|c" .. RAID_CLASS_COLORS[characterClass].colorStr .. Ambiguate(isAnUpgradeForAnyCharacterNames[isUpIndex], 'short') .. "|r"
						if isUpIndex ~= #isAnUpgradeForAnyCharacterNames then
							text = text .. ", "
						end
					end
					
					
					if has_value(isAnUpgradeForAnyCharacterNames, PLM_GetFullName('player')) == true then
						local button = EA_PLM:CreateButton(L["ASK_BUTTON"], 80, -25 - INDENT/2, verticalOffset - VERTICAL_SPACING)
							button:SetScript('OnClick', function(self)
								SendWhisp(lootedItem)
							end)
					end
					
					EA_PLM:CreateLabel(text, color, contentFrame, 'TOPLEFT', 0, verticalOffset)								
					verticalOffset = verticalOffset + VERTICAL_SPACING

				end
			end
		end
		
		if math.abs(verticalOffset) > lootedItemsFrame:GetHeight() then
				scrollbar:Show()
			else
				scrollbar:Hide()
			end

			EA_PLM:HideOffScreenWidgets()

			lootedItemsFrame:Show()

	else
		lootedItemsFrame:Hide()
	end
end











































